@@ -11,6 +11,7 @@ from datetime import datetime
 from io import open
 from collections import namedtuple
 from sqlite3 import OperationalError
+import shutil
 
 from cli_helpers.tabular_output import TabularOutputFormatter
 from cli_helpers.tabular_output import preprocessors
@@ -815,7 +816,7 @@ class LiteCli(object):
         """Get the number of lines to reserve for the completion menu."""
         reserved_space_ratio = 0.45
         max_reserved_space = 8
-        _, height = click.get_terminal_size()
+        _, height = shutil.get_terminal_size()
         return min(int(round(height * reserved_space_ratio)), max_reserved_space)
 
     def get_last_query(self):
